# Change Log of user_agent Library

## [1.4.0] - 2019-01-24
### Added
- Add Opera navigators for Windows, Linux, MAC OS, Android and iPhone OS

## [1.3.0] - 2019-01-23
### Added
- Add Safari navigators for MAC OS

## [1.2.0] - 2019-01-23
### Added
- Add Firefox and Safari navigators for iPhone OS
- Delete redundant code

## [1.1.0] - 2019-01-22
### Added
- New OS: iOS
- Add Google Chrome for iPhone OS

## [1.0.0] - 2019-01-21
### Very Important Update
- Add a User-Agent generator.
- The `gua` script for generating user-agent data in console.
- **Support**: Desktop, smartphone.
> **Windows**: Chrome, Firefox, IE, Edge  
> **Linux**: Chrome, Firefox  
> **Mac**: Chrome, Firefox  
> **Android**: Chrome, Firefox
